==> nextcloud-20.0.13.tgz: nextcloud/apps/weather_status/l10n/lt_LT.js <==
OC.L10N.register(
    "weather_status",
    {
    "Unknown address" : "Nežinomas adresas",
    "No result." : "Nėra rezultatų.",
    "Malformed JSON data." : "Netaisyklingi JSON duomenys.",
    "Error" : "Klaida",
    "Weather status" : "Orų būsena",
    "Weather status in your dashboard" : "Orų būsena jūsų skydelyje",
    "Weather status integrated in the Dashboard app.\n    User's position can be automatically determined or manually defined. A 6 hours forecast is then displayed.\n    This status can also be integrated in other places like the Calendar app." : "Orų būsena, integruota į skydelio programėlę.\n    Naudotojo vieta gali būti nustatyta automatiškai arba apibrėžta rankiniu būdu. Tuomet yra rodoma 6 valandų orų prognozė.\n    Ši būsena taip pat gali būti integruota kitose vietose, kaip, pavyzdžiui, kalendoriaus programėlėje.",
    "Detect location" : "Aptikti vietą",
    "Set custom address" : "Nustatyti tinkintą adresą",
    "Favorites" : "Mėgstamos",
    "{temperature} {unit} Clear sky at {time}" : "{temperature} {unit} Giedra ties {time}",
    "{temperature} {unit} Cloudy at {time}" : "{temperature} {unit} Debesuota ties {time}",
    "{temperature} {unit} Fair day at {time}" : "{temperature} {unit} Giedra diena ties {time}",
    "{temperature} {unit} Fair night at {time}" : "{temperature} {unit} Giedra naktis ties {time}",
    "{temperature} {unit} Partly cloudy at {time}" : "{temperature} {unit} Su pragiedruliais ties {time}",
    "{temperature} {unit} Foggy at {time}" : "{temperature} {unit} Rūkas ties {time}",
    "{temperature} {unit} Light rain at {time}" : "{temperature} {unit} Silpnas lietus ties {time}",
    "{temperature} {unit} Rain at {time}" : "{temperature} {unit} Lietus ties {time}",
    "{temperature} {unit} Heavy rain at {time}" : "{temperature} {unit} Stiprus lietus ties {time}",
    "{temperature} {unit} Rain showers at {time}" : "{temperature} {unit} Liūtys ties {time}",
    "{temperature} {unit} Light rain showers at {time}" : "{temperature} {unit} Silpnos liūtys ties {time}",
    "{temperature} {unit} Heavy rain showers at {time}" : "{temperature} {unit} Stiprios liūtys ties {time}",
    "More weather for {adr}" : "Daugiau orų ties {adr}",
    "Loading weather" : "Įkeliami orai",
    "Set location for weather" : "Nustatyti vietą orams",
    "Remove from favorites" : "Šalinti iš mėgstamų",
    "Add as favorite" : "Pridėti kaip mėgstamą",
    "You are not logged in." : "Jūs nesate prisijungę.",
    "There was an error getting the weather status information." : "Gaunant orų būsenos informaciją, įvyko klaida.",
    "No weather information found" : "Nerasta jokios informacijos apie orus",
    "Location not found" : "Vieta nerasta",
    "There was an error setting the location address." : "Nustatant vietos adresą, įvyko klaida.",
    "There was an error setting the location." : "Nustatant vietą, įvyko klaida.",
    "There was an error saving the mode." : "Įrašant veikseną, įvyko klaida.",
    "There was an error using personal address." : "Naudojant asmeninį adresą, įvyko klaida.",
    "Weather status integrated in the dashboard app.\n    User's position can be automatically determined or manually defined. A 6 hours forecast is then displayed.\n    This status can also be integrated in other places like the Calendar app." : "Orų būsena, integruota į skydelio programėlę.\n    Naudotojo vieta gali būti nustatyta automatiškai arba apibrėžta rankiniu būdu. Tuomet yra rodoma 6 valandų orų prognozė.\n    Ši būsena taip pat gali būti integruota kitose vietose, kaip, pavyzdžiui, kalendoriaus programėlėje."
},
"nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");

==> nextcloud-21.0.8.tgz: nextcloud/apps/weather_status/l10n/lt_LT.js <==
OC.L10N.register(
    "weather_status",
    {
    "Unknown address" : "Nežinomas adresas",
    "No result." : "Nėra rezultatų.",
    "Malformed JSON data." : "Netaisyklingi JSON duomenys.",
    "Error" : "Klaida",
    "Weather status" : "Orų būsena",
    "Weather status in your dashboard" : "Orų būsena jūsų skydelyje",
    "Weather status integrated in the Dashboard app.\n    User's position can be automatically determined or manually defined. A 6 hours forecast is then displayed.\n    This status can also be integrated in other places like the Calendar app." : "Orų būsena, integruota į skydelio programėlę.\n    Naudotojo vieta gali būti nustatyta automatiškai arba apibrėžta rankiniu būdu. Tuomet yra rodoma 6 valandų orų prognozė.\n    Ši būsena taip pat gali būti integruota kitose vietose, kaip, pavyzdžiui, kalendoriaus programėlėje.",
    "Detect location" : "Aptikti vietą",
    "Set custom address" : "Nustatyti tinkintą adresą",
    "Favorites" : "Mėgstamos",
    "{temperature} {unit} cloudy" : "{temperature} {unit} debesuota",
    "{temperature} {unit} foggy" : "{temperature} {unit} ūkanota",
    "More weather for {adr}" : "Daugiau orų ties {adr}",
    "Loading weather" : "Įkeliami orai",
    "Remove from favorites" : "Šalinti iš mėgstamų",
    "Add as favorite" : "Pridėti kaip mėgstamą",
    "You are not logged in." : "Jūs nesate prisijungę.",
    "There was an error getting the weather status information." : "Gaunant orų būsenos informaciją, įvyko klaida.",
    "No weather information found" : "Nerasta jokios informacijos apie orus",
    "Location not found" : "Vieta nerasta",
    "There was an error setting the location address." : "Nustatant vietos adresą, įvyko klaida.",
    "There was an error setting the location." : "Nustatant vietą, įvyko klaida.",
    "There was an error saving the mode." : "Įrašant veikseną, įvyko klaida.",
    "There was an error using personal address." : "Naudojant asmeninį adresą, įvyko klaida.",
    "Set location for weather" : "Nustatyti vietą orams",
    "Weather status integrated in the dashboard app.\n    User's position can be automatically determined or manually defined. A 6 hours forecast is then displayed.\n    This status can also be integrated in other places like the Calendar app." : "Orų būsena, integruota į skydelio programėlę.\n    Naudotojo vieta gali būti nustatyta automatiškai arba apibrėžta rankiniu būdu. Tuomet yra rodoma 6 valandų orų prognozė.\n    Ši būsena taip pat gali būti integruota kitose vietose, kaip, pavyzdžiui, kalendoriaus programėlėje.",
    "{temperature} {unit} Clear sky at {time}" : "{temperature} {unit} Giedra ties {time}",
    "{temperature} {unit} Cloudy at {time}" : "{temperature} {unit} Debesuota ties {time}",
    "{temperature} {unit} Fair day at {time}" : "{temperature} {unit} Giedra diena ties {time}",
    "{temperature} {unit} Fair night at {time}" : "{temperature} {unit} Giedra naktis ties {time}",
    "{temperature} {unit} Partly cloudy at {time}" : "{temperature} {unit} Su pragiedruliais ties {time}",
    "{temperature} {unit} Foggy at {time}" : "{temperature} {unit} Rūkas ties {time}",
    "{temperature} {unit} Light rain at {time}" : "{temperature} {unit} Silpnas lietus ties {time}",
    "{temperature} {unit} Rain at {time}" : "{temperature} {unit} Lietus ties {time}",
    "{temperature} {unit} Heavy rain at {time}" : "{temperature} {unit} Stiprus lietus ties {time}",
    "{temperature} {unit} Rain showers at {time}" : "{temperature} {unit} Liūtys ties {time}",
    "{temperature} {unit} Light rain showers at {time}" : "{temperature} {unit} Silpnos liūtys ties {time}",
    "{temperature} {unit} Heavy rain showers at {time}" : "{temperature} {unit} Stiprios liūtys ties {time}"
},
"nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
